
/*
 * Osmo - a handy personal organizer
 *
 * Copyright (C) 2007 Tomasz Maka <pasp@users.sourceforge.net>
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
 */

#ifndef _OPTIONS_GUI_H
#define _OPTIONS_GUI_H

#include "gui.h"

enum {
    OPT_PAGE_CALENDAR = 0,
    OPT_PAGE_TASKS,
    OPT_PAGE_CONTACTS,
#ifdef HAVE_LIBGRINGOTTS
    OPT_PAGE_NOTES,
#endif  /* HAVE_LIBGRINGOTTS */
    OPT_PAGE_GENERAL,
    OPT_NUMBER_OF_PAGES
};

void    gui_create_options      (GUI *appGUI);
void    options_switch_buttons  (gboolean left, GUI *appGUI);

#endif /* _OPTIONS_GUI_H */

